@@ -106,7 +106,12 @@ bool Methods::scrStart(void)
 		if(sym)
 			ScriptInterp::commit(sym, "none");
 		if(!scriptEvent("start:invalid"))
-			error("start-incomplete");
+		{
+			if(!stricmp(line->cmd, "connect"))
+				error("connect-incomplete");
+			else
+				error("start-incomplete");
+		}
 		return true;
 	}
 
@@ -119,8 +124,13 @@ bool Methods::scrStart(void)
 	{
 		if(sym)
 			ScriptInterp::commit(sym, "none");
-		if(!scriptEvent("start:failed"))
-			error("start-invalid");
+		if(!stricmp(line->cmd, "connect"))
+		{
+			if(!scriptEvent("dial:failed"))
+				error("dial-failed");
+		}
+		else if(!scriptEvent("start:failed"))
+			error("start-failed");
 		return true;
 	}
 
