@@ -49,8 +49,6 @@ unsigned Bayonne::compile_count;
 volatile bool Bayonne::image_loaded = false;
 volatile unsigned short Bayonne::total_active_calls = 0;
 
-Audio::Encoding Bayonne::peer_encoding = Audio::unknownEncoding;
-Audio::timeout_t Bayonne::peer_framing = 0;
 BayonneTranslator *Bayonne::init_translator = NULL;
 const char *Bayonne::init_voicelib = "none/prompts";
 
@@ -481,6 +479,9 @@ BayonneSession *Bayonne::getSession(timeslot_t timeslot)
 	if(!timeslots)
 		return NULL;
 
+	if(timeslot == NO_TIMESLOT)
+		return NULL;
+
 	if(timeslot >= ts_count)
 		return NULL;
 
@@ -723,6 +724,12 @@ BayonneSession *Bayonne::startDialing(const char *dial, const char *name, const
 
 	setString(buffer, sizeof(buffer), dial);
 	sp = strchr(buffer, ':');
+	if(!sp)
+	{
+		setString(buffer, sizeof(buffer), name);
+		sp = strchr(buffer, ':');
+	}
+	
 	if(!sp)
 	{
 		if(d)
@@ -733,13 +740,19 @@ BayonneSession *Bayonne::startDialing(const char *dial, const char *name, const
 			return NULL;
 		goto protocol;
 	}
-	*sp = 0;
-	d = BayonneDriver::get(buffer);
+	if(sp)
+		*sp = 0;
+	if(stricmp(buffer, "trunk"))
+		d = BayonneDriver::get(buffer);
+
 	if(!d)
 		return NULL;
-	
-	dial = strchr(dial, ':') + 1;
-	goto protocol;
+
+	if(strchr(dial, ':'))
+		dial = strchr(dial, ':') + 1;
+	cp = d->getLast("type");
+	if(cp && !stricmp(cp, "proto"))
+		goto protocol;
 
 trunking:
 	img = useImage();
@@ -774,7 +787,7 @@ trunking:
                 idx = 0;
                 cp = strchr(sel->cmd, '.');
                 if(cp && !stricmp(cp, ".span"))
-                     while(NULL != (cp = sel->args[idx++]))
+                     while(idx < sel->argc && NULL != (cp = sel->args[idx++]))
                 {
                         span = BayonneSpan::get(atoi(cp));
                         if(!span)
@@ -793,7 +806,7 @@ trunking:
                                 session->leave();
                         }
                 }
-                else while(NULL != (cp = sel->args[idx++]))
+                else while(idx < sel->argc && NULL != (cp = sel->args[idx++]))
                 {
                         session = getSid(cp);
                         if(!session)
@@ -848,13 +861,13 @@ protocol:
 	else if(sel)
 	{
 moreproxies:
-		while(sel->args[idx])
+		while(idx < sel->argc && sel->args[idx])
 		{
 			if(d->isReachable(sel->args[idx]))
 				break;
 			++idx;
 		}
-		if(!sel->args[idx])
+		if(idx >= sel->argc || !sel->args[idx])
 		{
 			if(!sel->next)
 				return NULL;
