@@ -119,8 +119,6 @@ public:
 	static unsigned compile_count;
 	static volatile bool image_loaded;
 
-	static Audio::Encoding peer_encoding;
-	static Audio::timeout_t peer_framing;
 	static BayonneTranslator *init_translator;
 	static const char *init_voicelib;
 	static AtomicCounter libexec_count;
