@@ -258,14 +258,7 @@ Thread(atoi(getLast("priority")), atoi(getLast("stack")) * 1024 + 8192)
 	cp = getLast("rate");
 	if(cp)
 		info.rate = atol(cp);
-	if(peer_encoding != Audio::unknownEncoding)
-	{
-		if(peer_encoding != Audio::pcm16Mono)	
-			info.encoding = peer_encoding;
-		info.setFraming(peer_framing);
-	}
-	else
-		info.setFraming(atol(getLast("framing")));
+	info.setFraming(atol(getLast("framing")));
 	registry = false;
 	cp = server->getLast("serverconfig");
 	if(cp)
@@ -1011,6 +1004,10 @@ fail401:
 	snprintf(buf, sizeof(buf), 
 		"%s:%s", contact->url->host, contact->url->port);
 
+
+	if(reg->proxy)
+		printf("PROXY %s TO %s\n", reg->proxy, buf);
+
 	if(!reg->proxy || stricmp(buf, reg->proxy))
 	{
 		cp = (char *)img->getMemory(strlen(buf));
