@@ -43,12 +43,6 @@ TimerPort()
 
 	peer_buffer = NULL;
 	peer_codec = NULL;
-
-	if(Driver::peer_encoding == Audio::pcm16Mono)
-	{
-		peer_buffer = new Sample[Driver::sip.info.framecount];
-		peer_codec = AudioCodec::getCodec(Driver::sip.info);
-	} 
 }
 
 Session::~Session()
