@@ -18,7 +18,7 @@
 #include <cc++/slog.h>
 #include <cc++/socket.h>
 
-namespace module {
+namespace moduleTCP {
 using namespace ost;
 using namespace std;
 
