@@ -18,11 +18,7 @@
 #include <cc++/process.h>
 #include <cc++/slog.h>
 
-#ifdef	WIN32
-#ifdef	_DEBUG
-#define	HAVE_TESTING
-#endif
-#else
+#ifndef	WIN32
 #include "private.h"
 #endif
 
@@ -314,15 +310,14 @@ extern BayonneConfig keyurl;
 extern TimeslotProperty typeTimeslot;
 extern PositionProperty typePosition;
 
+extern bool flag_daemon;
+extern bool flag_check;
+
 void purgedir(const char *dir);
 void loadConfig(void);
 void liveConfig(void);
 void dumpConfig(Keydata &keydef);
 bool parseConfig(char **argv);
 
-#ifdef	HAVE_TESTING
-void testConfig(char *argv0);
-#endif
-
 }
 
